Portal
SourceSummary↑
| push_left(portal) | Pushes data to the left in the given |
| push_right(portal) | Pushes data to the right in the given |
| shoot(color) | Shoots a new door with the given |
| start(type, args) | Callback implementation of |
| transfer(left, right, data) | Starts transfering |
Functions
Pushes data to the left in the given portal.
Pushes data to the right in the given portal.
Shoots a new door with the given color.
Callback implementation of :application.start/2.
Starts transfering data from left to right.