Portal.Door
SourceSummary↑
| get(door) | Get the data currently in the |
| pop(door) | Pops a value from the |
| push(door, value) | Push |
| start_link(color) | Starts a door with the given |
Functions
Get the data currently in the door.
Pops a value from the door.
It returns {:ok, value} if there is a value
or :error if the whole is currently empty.
Push value into the door.
Starts a door with the given color.
The color is given as a name so we can identify the door by color name instead of using a PID.